package cz.fidentis.analyst.core;

import cz.fidentis.analyst.canvas.Canvas;
import cz.fidentis.analyst.toolbar.FaceToFaceToolBar;
import cz.fidentis.analyst.toolbar.RenderingToolBar;
import javax.swing.GroupLayout;
import javax.swing.LayoutStyle;
import org.netbeans.api.settings.ConvertAsProperties;
import org.openide.windows.TopComponent;

/**
 * The non-singleton window/tab for the analysis of two faces.
 * For the discussion on crating non-singleton top component, 
 * see {@link http://netbeans.apache.org/wiki/DevFaqNonSingletonTopComponents.asciidoc}.
 *
 * @author Radek Oslejsek
 */
@ConvertAsProperties(
        dtd = "-//cz.fidentis.analyst.gui.tab//FaceToFaceTab//EN",
        autostore = false
)
public class FaceToFaceTab extends TopComponent {
    
    public static final int CONTROL_PANEL_WIDTH = 600;
    
    private final Canvas canvas = new Canvas();
    private final FaceToFaceToolBar renderingToolBar;
    private final TopControlPanel controlPanel;

    /**
     * Constructor.
     */
    public FaceToFaceTab() {
        controlPanel = new TopControlPanel();
        renderingToolBar = new FaceToFaceToolBar(canvas, controlPanel);
        initComponents();
    }
    
    @Override
    public int getPersistenceType() {
        return TopComponent.PERSISTENCE_NEVER; // TO DO: change to .PERSISTENCE_ONLY_OPENED when we can re-create the ProjectTC
    }
    
    private void initComponents() {
        GroupLayout layout = new GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
                layout.createParallelGroup(GroupLayout.Alignment.LEADING)
                        .addGroup(layout.createSequentialGroup()
                                .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(canvas, GroupLayout.DEFAULT_SIZE, 651, Short.MAX_VALUE)
                                .addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(renderingToolBar, GroupLayout.PREFERRED_SIZE, RenderingToolBar.WIDTH, GroupLayout.PREFERRED_SIZE)
                                .addComponent(controlPanel, CONTROL_PANEL_WIDTH, CONTROL_PANEL_WIDTH, CONTROL_PANEL_WIDTH)
                        )
        );
        layout.setVerticalGroup(
                layout.createParallelGroup(GroupLayout.Alignment.LEADING)
                        .addGroup(layout.createSequentialGroup()
                                .addGroup(layout.createBaselineGroup(true, true)
                                        .addComponent(canvas)
                                        .addComponent(renderingToolBar)
                                        .addComponent(controlPanel)
                                ))
        );
    }

    @Override
    public void componentOpened() {
        // TODO add custom code on component opening
    }

    @Override
    public void componentClosed() {
        // TODO add custom code on component closing
    }

    void writeProperties(java.util.Properties p) {
        // better to version settings since initial version as advocated at
        // http://wiki.apidesign.org/wiki/PropertyFiles
        p.setProperty("version", "1.0");
        // TODO store your settings
    }

    void readProperties(java.util.Properties p) {
        String version = p.getProperty("version");
        // TODO read your settings according to their version
    }
    
    public Canvas getCanvas() {
        return canvas;
    }
    
}
