package cz.fidentis.analyst.curvature;

import cz.fidentis.analyst.canvas.Canvas;
import cz.fidentis.analyst.visitors.mesh.Curvature;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.JComboBox;
import javax.swing.JTabbedPane;
import javax.swing.JToggleButton;

/**
 * Action listener for the curvature computation.
 * 
 * @author Radek Oslejsek
 */
public class CurvatureAction extends AbstractAction {
    
    public static final String ACTION_COMMAND_SHOW_HIDE_PANEL = "show-hide curvature control panel";
    public static final String ACTION_COMMAND_SHOW_HIDE_HEATMAP = "show-hide heatmap";
    public static final String ACTION_COMMAND_SET_CURVATURE_TYPE = "set curvature type";
    
    private final CurvaturePanel controlPanel;
    private final JTabbedPane topControlPanel;
    private final Canvas canvas;
    
    private Curvature curvatureVisitor = null;
    private String curvatureType = CurvaturePanel.GAUSSIAN_CURVATURE;
    
    /**
     * Constructor.
     * 
     * @param topControlPanel Top component for placing control panels
     * @param canvas OpenGL canvas
     */
    public CurvatureAction(JTabbedPane topControlPanel, Canvas canvas) {
        this.canvas = canvas;
        this.controlPanel = new CurvaturePanel(this);
        this.topControlPanel = topControlPanel;
        //this.topControlPanel.add(controlPanel);
        //controlPanel.setVisible(false);
    }

    @Override
    public void actionPerformed(ActionEvent ae) {
        String action = ae.getActionCommand();
        
        switch (action) {
            case ACTION_COMMAND_SHOW_HIDE_PANEL:
                if (((JToggleButton) ae.getSource()).isSelected()) {
                    topControlPanel.addTab(CurvaturePanel.NAME, CurvaturePanel.ICON, controlPanel);
                    topControlPanel.setSelectedComponent(controlPanel); // focus
                } else {
                    topControlPanel.remove(controlPanel);
                }
                break;
            case ACTION_COMMAND_SHOW_HIDE_HEATMAP:
                if (((JToggleButton) ae.getSource()).isSelected()) {
                    setHeatmap();
                    canvas.getScene().getDrawableFace(0).setRenderHeatmap(true);
                } else {
                    canvas.getScene().getDrawableFace(0).setRenderHeatmap(false);
                }
                break;
            case ACTION_COMMAND_SET_CURVATURE_TYPE:
                this.curvatureType = (String) ((JComboBox) ae.getSource()).getSelectedItem();
                setHeatmap();
                break;
            default:
                throw new UnsupportedOperationException(action);
        }
        canvas.renderScene();
    }
    
    protected void setHeatmap() {
        if (curvatureVisitor == null) { // compute missing curvature
            this.curvatureVisitor = new Curvature();
            canvas.getScene().getDrawableFace(0).getModel().compute(curvatureVisitor);
        }
        
        switch (this.curvatureType) {
            case CurvaturePanel.GAUSSIAN_CURVATURE:
                    canvas.getScene().getDrawableFace(0).setHeatMap(curvatureVisitor.getGaussianCurvatures());
                break;
            case CurvaturePanel.MEAN_CURVATURE:
                    canvas.getScene().getDrawableFace(0).setHeatMap(curvatureVisitor.getMeanCurvatures());
                break;
            case CurvaturePanel.MIN_CURVATURE:
                    canvas.getScene().getDrawableFace(0).setHeatMap(curvatureVisitor.getMinPrincipalCurvatures());
                break;
            case CurvaturePanel.MAX_CURVATURE:
                    canvas.getScene().getDrawableFace(0).setHeatMap(curvatureVisitor.getMaxPrincipalCurvatures());
                break;
            default:
                throw new UnsupportedOperationException(curvatureType);
        }
        
    }
}
